==> parodia_admin-1.0.2.tar.gz: lib/core/repository/productPrice.repository.dart <==
// GET
// /api/v1/dashboard/products/prices/{id}

// PUT
// /api/v1/dashboard/products/prices/{id}

// DELETE
// /api/v1/dashboard/products/prices/{id}

// GET
// /api/v1/dashboard/products/prices

// POST
// /api/v1/dashboard/products/prices

// PUT
// /api/v1/dashboard/products/prices/multiple

// POST
// /api/v1/dashboard/products/prices/{id}/recover

import 'package:parodia_admin/core/dto/product_price.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductPriceRepository {
  ParodiaHTTP? _http;

  ProductPriceRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductPriceDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products/prices',
      param: id,
    );

    return ResponseItemDTO<ProductPriceDTO>(
      response: response,
      fromJson: ProductPriceDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductPriceDTO>> getAll({
    ProductPriceAndRatingQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products/prices',
      query: query,
    );

    return ResponseListDTO<ProductPriceDTO>(
      response: response,
      fromJson: ProductPriceDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PriceBody? price}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/prices',
      data: price,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PriceMultiplePutBody? productCatalogs}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/products/prices/multiple',
      data: productCatalogs,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductCatalogBody? price}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/products/prices',
      param: id,
      data: price,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/products/prices',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/prices/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/productPrice.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/products/prices/{id}

// PUT
// /api/v1/dashboard/dashboard/products/prices/{id}

// DELETE
// /api/v1/dashboard/dashboard/products/prices/{id}

// GET
// /api/v1/dashboard/dashboard/products/prices

// POST
// /api/v1/dashboard/dashboard/products/prices

// PUT
// /api/v1/dashboard/dashboard/products/prices/multiple

// POST
// /api/v1/dashboard/dashboard/products/prices/{id}/recover

import 'package:parodia_admin/core/dto/product_price.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductPriceRepository {
  ParodiaHTTP? _http;

  ProductPriceRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductPriceDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/products/prices',
      param: id,
    );

    return ResponseItemDTO<ProductPriceDTO>(
      response: response,
      fromJson: ProductPriceDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductPriceDTO>> getAll({
    ProductPriceAndRatingQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/products/prices',
      query: query,
    );

    return ResponseListDTO<ProductPriceDTO>(
      response: response,
      fromJson: ProductPriceDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PriceBody? price}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/products/prices',
      data: price,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, PriceMultiplePutBody? productCatalogs}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/products/prices/multiple',
      data: productCatalogs,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductCatalogBody? price}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/products/prices',
      param: id,
      data: price,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/products/prices',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/products/prices/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
